@@ -659,17 +659,16 @@ class CsvExporter:
                     )
                 )
             ]
-
         for image in get_json_property(item, MEDIA):
-            if EXT in image.keys():
-                if image[EXT]:
-                    media_list.append(image[MEDIAID] + "." + image[EXT])
+            if image:
+                if EXT in image.keys():
+                    if image[EXT]:
+                        media_list.append(image[MEDIAID] + "." + image[EXT])
+                    else:
+                        media_list.append(image[MEDIAID] + "." + "jpg")
                 else:
                     media_list.append(image[MEDIAID] + "." + "jpg")
-            else:
-                media_list.append(image[MEDIAID] + "." + "jpg")
         media_href = "\n".join(media_list)
-        # media_href = '\n'.join(image[MEDIAID]+'.'+image[EXT] for image in get_json_property(item, MEDIA))
         if media_href == ".":
             media_href = None
         return media_href
